(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18973,        374]*)
(*NotebookOutlinePosition[     45773,       1357]*)
(*  CellTagsIndexPosition[     45729,       1353]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Riga e Compasso\n",
  FontSize->18,
  FontWeight->"Bold"]], "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  GroupPageBreakWithin->Automatic,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["(* Punti *)",
    FontWeight->"Bold"],
  "\n\nUnprotect[Punto,Coord,Dist];\nClearAll[Punto,Coord,Dist];\n\n\
Coord[Punto[x_,y_]] := {x,y}\n\nDist[Punto[x1_,y1_],Punto[x2_,y2_]] := \
Sqrt[(x2 - x1)^2 + (y2 - y1)^2]\n"
}], "Input",
  PageBreakWithin->Automatic,
  GroupPageBreakWithin->Automatic,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["(* Rette e circonferenze *)\n",
    FontWeight->"Bold"],
  "\nUnprotect[Retta,Circonferenza];\nClearAll[Retta,Circonferenza];\n\n\
Retta[p_Punto,q_Punto] /; N[p == q] := \n  \
Message[Retta::indef,HoldForm[Retta[p,q]]]\n\nCirconferenza[c_Punto,r_] /; \
N[r <= 0] := \n  Message[Circonferenza::indef,HoldForm[Circonferenza[c,r]]]\n\
"
}], "Input",
  PageBreakWithin->Automatic,
  GroupPageBreakWithin->Automatic,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["(* Intersezione tra rette e circonferenze *)\n",
    FontWeight->"Bold"],
  "\nUnprotect[Intersezione];\nClearAll[Intersezione];\n\n\
Intersezione[R1:Retta[p1_,p2_],R2:Retta[p3_,p4_]] :=\n  Module[{v1 = \
Coord[p2] - Coord[p1],\n          v2 = Coord[p4] - Coord[p3],\n          v3 = \
Coord[p3] - Coord[p1]},\n  Module[{d12 = Det[{v1,v2}],\n          d13 = \
Det[{v1,v3}]},\n    If[(Chop[N[d12]] == 0) === True,\n       If[(Chop[N[d13]] \
== 0) === True,\n          Message[Intersezione::indef,R1,R2],\n          \
Message[Intersezione::vuota,R1,R2]],\n       Punto[p1[[1]] - d13/d12 v1[[1]],\
\n             p1[[2]] - d13/d12 v1[[2]]]]]]\n\n\
Intersezione[R1:Retta[p1_,p2_],C2:Circonferenza[c_,r_],i:1|2] := \n  \
Module[{v1 = Coord[p2] - Coord[p1],\n          v2 = Coord[c] - Coord[p1],d},\n\
    If[(Chop[N[d = (v1.v2)^2-(v1.v1)(v2.v2-r^2)]] < 0) === True,\n       \
Message[Intersezione::vuota,R1,C2],\n       Punto[p1[[1]] + (v1.v2 +(-1)^i \
Sqrt[d])/(v1.v1) v1[[1]],\n             p1[[2]] + (v1.v2 +(-1)^i \
Sqrt[d])/(v1.v1) v1[[2]]]]]\n       \n\
Intersezione[C1_Circonferenza,R2_Retta,i:1|2] := Intersezione[R2,C1,i]\n\n\
Intersezione[C1:Circonferenza[c1_,r1_],C2:Circonferenza[c2_,r2_],i:1|2] :=\n  \
If[And[Chop[N[r1 - r2]] == 0,\n         Chop[N[Coord[c1] - Coord[c2]]] == \
{0,0}] === True,\n     Message[Intersezione::indef,C1,C2],\n     Module[{d = \
Dist[c1,c2]},\n       If[Or[Chop[N[r1 + r2 - d]] < 0.,\n             \
Chop[N[r1 - r2 - d]] > 0,\n             Chop[N[r2 - r1 - d]] > 0] === True,\n \
         Message[Intersezione::vuota,C1,C2],\n          Module[{t = (d^2 + \
r1^2 - r2^2)/(2 d^2),\n                  s = (-1)^i Sqrt[(r1^2 - (d - r2)^2)\n\
                                  ((d + r2)^2 - r1^2)]/(2 d^2)},\n            \
Punto[(1 - t) c1[[1]] + t c2[[1]] - s (c2[[2]] - c1[[2]]),\n                  \
(1 - t) c1[[2]] + t c2[[2]] + s (c2[[1]] - c1[[1]])]]]]]\n"
}], "Input",
  PageBreakWithin->Automatic,
  GroupPageBreakWithin->Automatic,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["(* Segmenti e archi *)\n                 ",
    FontWeight->"Bold"],
  "\nUnprotect[Segmento,Arco];\nClearAll[Segmento,Arco];\n\n\
Segmento[p_Punto,q_Punto] /; N[p == q] := \n  \
Message[Segmento::indef,HoldForm[Segmento[p,q]]]\n\nArco[c_Punto,p_Punto] /; \
N[c == p] := \n  Message[Arco::indef,HoldForm[Arco[c,p]]]\n\
Arco[c_Punto,p_Punto,q_Punto] /; N[c == p] || N[c == q] := \n  \
Message[Arco::indef,HoldForm[Arco[c,p,q]]]\n"
}], "Input",
  PageBreakWithin->Automatic,
  GroupPageBreakWithin->Automatic,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["(* Poligoni *)",
    FontWeight->"Bold"],
  "\n\nUnprotect[Poligono];\nClearAll[Poligono];\n\nPoligono[p_Punto] := \
Message[Poligono::indef,HoldForm[Poligono[p]]]\nPoligono[p_Punto,q_Punto] := \
\n  Message[Poligono::indef,HoldForm[Poligono[p,q]]]\n"
}], "Input",
  PageBreakWithin->Automatic,
  GroupPageBreakWithin->Automatic,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["(* Isometrie *)",
    FontWeight->"Bold"],
  "\n\nUnprotect[Isometria];\nClearAll[Isometria];\n\n\
Isometria[Punto[x1_Symbol,y1_Symbol] -> Punto[x2_,y2_]][Punto[x_,y_]] := \n  \
Function[{x1,y1},Punto[x2,y2]][x,y]\n\n(f:Isometria[_])[Retta[p_,q_]] := \
Retta[f[p],f[q]]\n(f:Isometria[_])[Circonferenza[c_,r_]] := \
Circonferenza[f[c],r]\n(f:Isometria[_])[Segmento[p_,q_]] := \
Segmento[f[p],f[q]]\n(f:Isometria[_])[Arco[c_,p_,q_]] := Arco[f[c],f[p],f[q]]\
\n(f:Isometria[_])[Poligono[pp__]] := Map[f,Poligono[pp]]\n\n\
(f:Isometria[_])[l_List] := Map[f,l]\n(f:Isometria[_])[x_] := x\n"
}], "Input",
  PageBreakWithin->Automatic,
  GroupPageBreakWithin->Automatic,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["(* Rappresentazione grafica *)",
    FontWeight->"Bold"],
  "\n\nUnprotect[Disegno,Stile,Colore,Spessore,Tratto,Code,Caratteri];\n\
Unprotect[Giallo,Rosso,Verde,Blu,Nero,Grigio,Bianco];\n\
Unprotect[Testo,Etichetta,C,S,D,A,B,SA,SB,DA,DB,Ind,NoInd];\n\
Unprotect[Attivo,NonAttivo,Indicizzato,NonIndicizzato];\n\
Unprotect[DisOgg$,Etic$,Txt$,Seq$,pt$,np$,no$,po$,at$,mo$,mv$,dv$,rd$];\n\
ClearAll[Disegno,Stile,Colore,Spessore,Tratto,Code,Caratteri];\n\
ClearAll[Giallo,Rosso,Verde,Blu,Nero,Grigio,Bianco];\n\
ClearAll[Testo,Etichetta,C,S,D,A,B,SA,SB,DA,DB,Ind,NoInd];\n\
ClearAll[Attivo,NonAttivo,Indicizzato,NonIndicizzato];\n\
ClearAll[DisOgg$,Etic$,Txt$,Seq$,pt$,np$,no$,po$,at$,mo$,mv$,dv$,rd$];\n\npt$ \
= _?(MatchQ[#,_Punto]&);\nnp$ = _?(Not[MatchQ[#,_Punto]]&);\n\n\
Disegno[oggetti_,lx:{_,_}:{-2,2},\n                 \
ly:{_,_}:{-2,2},opts___Rule] :=\n  Show[Graphics[Block[{lx$ = lx,ly$ = ly},\n \
   DisOgg$[{Stile[Colore -> Nero,Spessore -> 0.1,Tratto -> 0,Code -> 0.,\n    \
               Testo -> {Attivo,Indicizzato},Caratteri -> {10,Nero}],         \
  \n             Unevaluated[oggetti],\n             Stile[Colore -> \
Grigio[0.4],\n                   Line[{{lx[[1]],ly[[1]]},{lx[[2]],ly[[1]]},\n \
                        {lx[[2]],ly[[2]]},{lx[[1]],ly[[2]]},\n                \
         {lx[[1]],ly[[1]]}}]]}] /. Seq$ -> Sequence],\n    {PlotRange -> \
{lx,ly},AspectRatio -> Automatic,opts}]]\n  \nDisOgg$[pun:Punto[x_,y_]] := \
(pun;Point[{x,y}])\n\nDisOgg$[ret:Retta[p1:pt$,p2:pt$]] :=\n (ret;Module[{v = \
N[Coord[p2] - Coord[p1]],\n              t = 2 (Abs[p1[[1]]] + Abs[lx$[[1]]] \
+ Abs[lx$[[2]]] +\n                     Abs[p1[[2]]] + Abs[ly$[[1]]] + \
Abs[ly$[[2]]])},\n        Line[{Coord[p1] - t v,Coord[p1] + t v}]])\n         \
\nDisOgg$[cir:Circonferenza[c:pt$,r:np$]] := (cir;Circle[Coord[c],r])\n\n\
DisOgg$[seg:Segmento[p1:pt$,p2:pt$]] := \n  (seg;Module[{d = N[Coord[p2] - \
Coord[p1]]},\n         Line[{Coord[p1] - ini$ d / Sqrt[d.d],\n               \
Coord[p2] + fin$ d / Sqrt[d.d]}]])\nDisOgg$[seg:Segmento[p:pt$,a:np$]] := \n  \
(seg;Line[{Coord[p] - ini$ {Cos[a],Sin[a]},\n            Coord[p] + fin$ \
{Cos[a],Sin[a]}}])\n        \nDisOgg$[arc:Arco[c:pt$,p1:pt$,p2:pt$]] := \n  \
(arc;Module[{a1 = N[Apply[ArcTan,Coord[p1] - Coord[c]]],\n               a2 = \
N[Apply[ArcTan,Coord[p2] - Coord[c]]],\n               ai = \
N[ini$/Dist[c,p1]],af = N[fin$/Dist[c,p1]]},\n         \
Circle[Coord[c],Dist[c,p1],\n                {a1 - ai,If[a2 >= a1,a2,a2 + \
2Pi] + af}]])\nDisOgg$[Arco[c:pt$,p:pt$]] := DisOgg$[Arco[c,p,p]]\n\n\
DisOgg$[pol:Poligono[p:pt$,q:pt$..]] := \n  (pol;Block[{ini$ = 0.,fin$ = \
0.},Line[Map[Coord,{p,q,p}]]])\n     \nDisOgg$[Stile[st__]] := \n  Seq$[st] \
/. {(Colore -> c_) :> Apply[RGBColor,N[c]],\n               (Spessore -> s_) \
:> Seq$[AbsoluteThickness[2.85 s],\n                                        \
AbsolutePointSize[2.85 s]],\n               (Tratto -> 0) :> \
AbsoluteDashing[{}],\n               (Tratto -> t_List) :> \
AbsoluteDashing[2.85 t],\n               (Tratto -> t_) :> \
AbsoluteDashing[2.85 {t}],\n               (Code -> {i_,f_}) :> (ini$ = 0.1 \
i;fin$ = 0.1 f;{}),\n               (Code -> c_) :> (ini$ = 0.1 c;fin$ = 0.1 \
c;{}),\n               (Caratteri -> f_) :>  \n                 (f /. {d:no$ \
:> (dim$ = d),\n                        c:{no$..} :> (col$ = \
Apply[RGBColor,N[c]])};{}),\n               (Testo -> t_) :>\n                \
 (t /. {Attivo :> (ToStr$ = ToString),\n                        NonAttivo :> \
(ToStr$ = (\"  \")&),\n                        Indicizzato :> (ind$ = Ind),\n \
                       NonIndicizzato :> (ind$ = NoInd)};{})}\n\n\
DisOgg$[Stile[st__][o_]] := DisOgg$[{Stile[st],o}]\n\n\
DisOgg$[Literal[Set][n_,Stile[st__][o_]]] := DisOgg$[{Stile[st],n = o}]\n\n\
no$ = _?(NumberQ[N[#]]&);\npo$ = \
_?(MatchQ[#,C|S|D|A|B|SA|SB|DA|DB|{no$,no$}]&);\nat$ = \
no$|{no$,no$}|(po$)|Ind|NoInd;\n\nmo$ = 1.;mv$ = .25;dv$ = .5;rd$ = .8;\n\n\
DisOgg$[Testo[s_HoldForm,r__]] := Txt$[s,r]\nDisOgg$[Testo[s_,r__]] := \
Txt$[HoldForm[s],r]\n\nTxt$[s_,{x_,y_},pos:(po$):DA] := \
Txt$[s,{x,y},pos,ind$]\n\nTxt$[s_,{x_,y_},pos:(po$):DA,NoInd] := \n  \
Module[{t = ToStr$[s]},\n  Module[{lt = StringLength[t]},\n  Module[{p = {1 + \
mo$/lt,1 + mv$} * \n              Replace[pos,{C->{0,0},A->{0,-1},B->{0,1},\n \
                          S->{1,0},SA->{1,-1},SB->{1,1},\n                    \
       D->{-1,0},DA->{-1,-1},DB->{-1,1}}]},\n    \
{col$,Text[FontForm[t,{\"Courier\",dim$}],{x,y},p]}]]]\n    \n\
Txt$[s_,{x_,y_},pos:(po$):DA,Ind] := \n  Module[{t = \
ToStr$[Replace[s,HoldForm[h_[p___]] :> HoldForm[h]]],\n          i = \
If[Depth[s]==2,\"\",\n                 StringReplace[StringTake[\n            \
       ToStr$[Replace[s,HoldForm[h_[p___]] :> HoldForm[{p}]]],\n              \
     {2,-2}],\" \" -> \"\"]]},\n  Module[{lt = StringLength[t],li = \
StringLength[i]},\n    If[li == 0,Txt$[s,{x,y},pos,NoInd],\n       Module[{p \
= {(2 lt + 2 mo$ + 2 li rd$)/(2 lt),1 + dv$/2 + mv$} *\n                   \
Replace[pos,{C->{0,0},A->{0,-1},B->{0,1},\n                                \
S->{1,0},SA->{1,-1},SB->{1,1},\n                                \
D->{-1,0},DA->{-1,-1},DB->{-1,1}}]},\n         \
{col$,Text[FontForm[t,{\"Courier\",dim$}],\n                    {x,y},p + \
{(li rd$)/lt,-dv$/2}],\n               Text[FontForm[i,{\"Courier\",rd$ \
dim$}],\n                    {x,y},p {lt/(rd$ li),1/rd$} + \n                 \
   {-lt/(li rd$),(2 + dv$)/(2 rd$) - 1}]}]]]]\n\n\
DisOgg$[Literal[Set][n_,Etichetta[o_]]] := \n  DisOgg$[{n = \
o,Etic$[HoldForm[n]][n]}]\n\
DisOgg$[Literal[Set][n_,Etichetta[a:at$,r___][o_]]] := \n  DisOgg$[{n = \
o,Etic$[HoldForm[n],a,r][n]}]\nDisOgg$[Literal[Set][n_,Etichetta[sat__][o_]]] \
:= \n  DisOgg$[{n = o,Etic$[sat][n]}]\n\nDisOgg$[Etichetta[Stile[st__][o_]]] \
:= \n  DisOgg$[{Stile[st][o],Etic$[HoldForm[o]][o]}]\n\
DisOgg$[Etichetta[a:at$,r___][Stile[st__][o_]]] := \n  \
DisOgg$[{Stile[st][o],Etic$[HoldForm[o],a,r][o]}]\n\
DisOgg$[Etichetta[sat__][Stile[st__][o_]]] := \n  \
DisOgg$[{Stile[st][o],Etic$[sat][o]}]\n  \nDisOgg$[Etichetta[o_]] := \
DisOgg$[{o,Etic$[HoldForm[o]][o]}]\nDisOgg$[Etichetta[a:at$,r___][o_]] := \n  \
DisOgg$[{o,Etic$[HoldForm[o],a,r][o]}]\nDisOgg$[Etichetta[sat__][o_]] := \
DisOgg$[{o,Etic$[sat][o]}]\n\nEtic$[sat___,i:Ind|NoInd][o_] := Block[{ind$ = \
i},Etic$[sat][o]]\n\nEtic$[s_,pos:(po$):DA][Punto[x_,y_]] := \n  \
Testo[s,N[{x,y}],pos,ind$]\nEtic$[s_,t:(no$):.5,pos:(po$):DA][Retta[p1_,p2_]] \
:=\n  Testo[s,N[(1-t)Coord[p1] + t Coord[p2]],pos,ind$]\n\
Etic$[s_,t:(no$):(Pi/4),pos:(po$):DA][Circonferenza[c_,r_]] :=\n  \
Testo[s,N[Coord[c] + r {Cos[t],Sin[t]}],pos,ind$]\n\
Etic$[s_,t:(no$):.5,pos:(po$):DA][Segmento[p1_,p2:pt$]] :=\n  \
Testo[s,N[(1-t)Coord[p1] + t Coord[p2]],pos,ind$]\n\
Etic$[s_,t:(no$):0.,pos:(po$):DA][Segmento[p_,a:np$]] :=\n  \
Testo[s,N[(1-t)Coord[p] + t {Cos[a],Sin[a]}],pos,ind$]\n\
Etic$[s_,t:(no$):.5,pos:(po$):DA][Arco[c_,p1_,p2_]] :=\n  Module[{a1 = \
N[Apply[ArcTan,Coord[p1] - Coord[c]]],\n          a2 = \
N[Apply[ArcTan,Coord[p2] - Coord[c]]]},\n  Module[{a = N[(1-t) a1 + t If[a2 \
>= a1,a2,a2 + 2Pi]]},\n         Testo[s,Coord[c] + Dist[c,p1] \
{Cos[a],Sin[a]},pos,ind$]]]\nEtic$[s_,t:(no$):0.,pos:(po$):DA][Arco[c_,p_]] \
:=\n  Module[{a = N[Apply[ArcTan,Coord[p1] - Coord[c]] + t/Dist[c,P1]]},\n    \
     Testo[s,Coord[c] + Dist[c,p1] {Cos[a],Sin[a]},pos,ind$]]\n\
Etic$[s_,pos:(po$):C][Poligono[p__]] :=\n  \
Testo[s,Apply[Plus,Map[Coord,{p}]]/Length[{p}],pos,ind$]\n\
Etic$[s_,x:{no$,no$},pos:(po$):DA][o_] := Testo[s,x,pos,ind$]\n\n\
DisOgg$[Literal[CompoundExpression[e__,f_]]] := \n  \
CompoundExpression[e,DisOgg$[f]]\n\nDisOgg$[l_List] := \n  Block[{ini$ = \
ini$,fin$ = fin$,\n         ToStr$ = ToStr$,col$ = col$,dim$ = dim$,ind$ = \
ind$},\n    Map[DisOgg$,Unevaluated[l]]]\n\n\
DisOgg$[x_/;(x$=x)=!=Unevaluated[x]] := DisOgg$[Evaluate[x$]]\n\nDisOgg$[x_] \
= {};\n\nSetAttributes[{Disegno,DisOgg$},HoldFirst];\n\nGiallo = {1.,1.,0.};\n\
Rosso = {1.,0.,0.};\nVerde = {0.,1.,0.};\nBlu = {0.,0.,1.};\n\nBianco = \
{1.,1.,1.};\nNero = {0.,0.,0.};\nGrigio[x_] := N[1 - x] Bianco;\n"
}], "Input",
  PageBreakWithin->Automatic,
  GroupPageBreakWithin->Automatic,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["(* Forme speciali *)",
    FontWeight->"Bold"],
  "\n\nRetta[Punto[x_,y_],a:np$] := \n  Retta[Punto[x,y],Punto[x + Cos[a],y + \
Sin[a]]]\n\nCirconferenza[c_Punto,c_] := \n  \
Message[Circonferenza::indef,HoldForm[Circonferenza[c,c]]]\n\
Circonferenza[c_Punto,p_Punto] := Circonferenza[c,Dist[c,p]]\n\n\
Arco[c_Punto,r_,a_] /; N[r <= 0] :=\n  \
Message[Arco::indef,HoldForm[Arco[c,a]]]\nArco[c_Punto,r_,a1_,a2_] /; N[r <= \
0] :=\n  Message[Arco::indef,HoldForm[Arco[c,a1,a2]]]\n\
Arco[Punto[x_,y_],r:np$,a_] := \n  Arco[Punto[x,y],Punto[x + r Cos[a],y + r \
Sin[a]]]\nArco[Punto[x_,y_],r:np$,a1_,a2_] := \n  Arco[Punto[x,y],Punto[x + r \
Cos[a1],y + r Sin[a1]],\n                  Punto[x + r Cos[a2],y + r \
Sin[a2]]]\n"
}], "Input",
  PageBreakWithin->Automatic,
  GroupPageBreakWithin->Automatic,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["(* Controllo sintassi *)",
    FontWeight->"Bold"],
  "\n\nPunto[] := Message[Punto::sint,HoldForm[Punto[]]]\nPunto[x_] := \
Message[Punto::sint,HoldForm[Punto[x]]]\nPunto[x_,y_,z__] := \
Message[Punto::sint,HoldForm[Punto[x,y,z]]]\n\nRetta[] := \
Message[Retta::sint,HoldForm[Retta[]]]\nRetta[p_] := \
Message[Retta::sint,HoldForm[Retta[p]]]\nRetta[p_,q_,r__] := \
Message[Retta::sint,HoldForm[Retta[p,q,r]]]\nRetta[p:np$,q_] := \
Message[Retta::sint,HoldForm[Retta[p,q]]]\n\nCirconferenza[] := \n  \
Message[Circonferenza::sint,HoldForm[Circonferenza[]]]\nCirconferenza[c_] := \
\n  Message[Circonferenza::sint,HoldForm[Circonferenza[c]]]\n\
Circonferenza[c_,r_,s__] := \n  \
Message[Circonferenza::sint,HoldForm[Circonferenza[c,r,s]]]\n\
Circonferenza[c:np$,r_] := \n  \
Message[Circonferenza::sint,HoldForm[Circonferenza[c,r]]]\n\nSegmento[] := \
Message[Segmento::sint,HoldForm[Segmento[]]]\nSegmento[p_] := \
Message[Segmento::sint,HoldForm[Segmento[p]]]\nSegmento[p_,q_,r__] := \
Message[Segmento::sint,HoldForm[Segmento[p,q,r]]]\nSegmento[p:np$,q_] := \
Message[Segmento::sint,HoldForm[Segmento[p,q]]]\n\nArco[] := \
Message[Arco::sint,HoldForm[Arco[]]]\nArco[c_] := \
Message[Arco::sint,HoldForm[Arco[c]]]\nArco[c:np$,p__] := \
Message[Arco::sint,HoldForm[Arco[c,p]]]\nArco[c_,p:pt$,q_,s__] := \
Message[Arco::sint,HoldForm[Arco[c,p,q,s]]]\nArco[c_,p:pt$,q:np$] := \
Message[Arco::sint,HoldForm[Arco[c,p,q]]]\nArco[c_,r:np$,a1_,a2_,b__] := \n  \
Message[Arco::sint,HoldForm[Arco[c,r,a1,a2,b]]]\nArco[c_,r:np$,a___] /; \
Not[MatchQ[{a},{np$..}]] :=\n  Message[Arco::sint,HoldForm[Arco[c,r,a]]]\n\n\
Poligono[] := Message[Poligono::sint,HoldForm[Poligono[]]]\nPoligono[p__] /; \
Not[MatchQ[{p},{pt$..}]] :=\n  Message[Poligono::sint,HoldForm[Poligono[p]]]\n\
"
}], "Input",
  PageBreakWithin->Automatic,
  GroupPageBreakWithin->Automatic,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["(* Messaggi *)",
    FontWeight->"Bold"],
  "\n\nPunto::sint = \" `1`\";\n\nRetta::sint = \" `1`\";\n\
Circonferenza::sint = \" `1`\";\n\nSegmento::sint = \" `1`\";\nArco::sint = \
\" `1`\";\n\nPoligono::sint = \" `1`\";\n\nRetta::indef = \" `1`\";\n\
Circonferenza::indef = \" `1`\";\n\nSegmento::indef = \" `1`\";\nArco::indef \
= \" `1`\";\n\nIntersezione::indef = \" `1`    `2`\";\nIntersezione::vuota = \
\" `1`    `2`\";\n"
}], "Input",
  PageBreakWithin->Automatic,
  GroupPageBreakWithin->Automatic,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Protect[Punto,Retta,Circonferenza,Segmento,Arco];
Protect[Coord,Dist,Intersezione,Isometria];
Protect[Disegno,Stile,Colore,Spessore,Tratto,Code,Caratteri];
Protect[Giallo,Rosso,Verde,Blu,Nero,Grigio,Bianco];
Protect[Testo,Etichetta,C,S,D,A,B,SA,SB,DA,DB,Ind,NoInd];
Protect[Attivo,NonAttivo,Indicizzato,NonIndicizzato];
Protect[DisOgg$,Etic$,Txt$,Seq$,pt$,np$,no$,po$,at$,mo$,mv$,dv$,rd$];
\
\>", "Input",
  PageBreakWithin->Automatic,
  GroupPageBreakWithin->Automatic,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}}]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{635, 633},
WindowMargins->{{17, Automatic}, {Automatic, 41}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    WindowSize->{565, Automatic},
    WindowMargins->{{2, Automatic}, {2, 2}},
    PageHeaders->{{None, None, None}, {None, None, None}},
    PageFooters->{{None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}},
    PageHeaderLines->{False, False},
    PageFooterLines->{False, False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontFamily->"Times"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{2, 6}, {32, 16}},
    Evaluatable->False,
    CellGroupingRules->{"TitleGrouping", 0},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{6, 6}, {8, 4}},
    LineSpacing->{1, 0},
    FontSize->48],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{6, 6}, {8, 4}},
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{2, 6}, {16, 8}},
    Evaluatable->False,
    CellGroupingRules->{"TitleGrouping", 10},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{6, 6}, {4, 2}},
    FontSize->32],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{6, 6}, {4, 2}},
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{2, 6}, {8, 4}},
    Evaluatable->False,
    CellGroupingRules->{"TitleGrouping", 20},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    LineSpacing->{1, 0},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{6, 6}, {2, 1}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{6, 6}, {2, 1}},
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{19, Inherited}, {12, 8}},
    Evaluatable->False,
    CellGroupingRules->{"SectionGrouping", 30},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSize->22,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{28, Inherited}, {6, 4}},
    LineSpacing->{1, 0},
    FontSize->28],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{28, Inherited}, {6, 4}},
    FontSize->16],
  
  Cell[StyleData["Section", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{19, Inherited}, {8, 6}},
    Evaluatable->False,
    CellGroupingRules->{"SectionGrouping", 40},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{28, Inherited}, {4, 2}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{28, Inherited}, {4, 2}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[EmptySquare]",
    CellMargins->{{19, Inherited}, {4, 2}},
    Evaluatable->False,
    CellGroupingRules->{"SectionGrouping", 50},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subsubsection",
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{28, Inherited}, {2, 2}},
    LineSpacing->{1, 0},
    FontSize->20],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{28, Inherited}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{19, Inherited}, {2, 2}},
    Evaluatable->False,
    CellHorizontalScrolling->False,
    PageBreakWithin->Automatic,
    LineSpacing->{1, 0},
    CounterIncrements->"Text",
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    FontSize->10],
  
  Cell[StyleData["Text", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{19, Inherited}, {2, 2}},
    Evaluatable->False,
    CellHorizontalScrolling->False,
    PageBreakWithin->Automatic,
    LineSpacing->{1, 0},
    CounterIncrements->"SmallText",
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["SmallText", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    PageWidth->Infinity,
    CellMargins->{{19, Inherited}, {2, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    PageWidth->Infinity,
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Condensed"],
    PageWidth->Infinity,
    CellMargins->{{17, Inherited}, {1, 2}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Input", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    PageWidth->Infinity,
    CellMargins->{{19, Inherited}, {2, 2}},
    CellEditDuplicate->True,
    Evaluatable->False,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Output",
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.00202945, 0.0522164, 0.539055]],
  
  Cell[StyleData["Output", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Output", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    PageWidth->Infinity,
    CellMargins->{{19, Inherited}, {2, 2}},
    Evaluatable->False,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Message",
    AspectRatioFixed->True,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.743709, 0.0139315, 0.0494698]],
  
  Cell[StyleData["Message", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Message", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    PageWidth->Infinity,
    CellMargins->{{19, Inherited}, {2, 2}},
    Evaluatable->False,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Print",
    AspectRatioFixed->True,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Print", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{19, Inherited}, {2, 2}},
    Evaluatable->False,
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Graphics",
    AspectRatioFixed->True,
    ImageSize->{200, 200},
    ImageMargins->{{18, 0}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Graphics", "Presentation"],
    ScriptSizeMultipliers->0.75,
    ImageSize->{800, 500},
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Graphics", "Printout"],
    ScriptSizeMultipliers->0.7,
    ImageSize->{500, 300}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{6, Inherited}, {2, 2}},
    LineSpacing->{1, 2},
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"]],
  
  Cell[StyleData["InlineFormula", "Condensed"]],
  
  Cell[StyleData["InlineFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{56, Inherited}, {4, 4}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 4},
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"]],
  
  Cell[StyleData["DisplayFormula", "Condensed"]],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{19, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    PageBreakWithin->Automatic,
    TextAlignment->Center,
    LineSpacing->{1, 0},
    AspectRatioFixed->True,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Footer"],
    CellMargins->{{19, 6}, {4, 4}},
    Evaluatable->False,
    PageBreakWithin->Automatic,
    TextAlignment->Center,
    TextJustification->0,
    LineSpacing->{1, 0},
    AspectRatioFixed->True,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    TextAlignment->Left,
    LineSpacing->{0.85, -3},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000ad2<?oYonl3<`920dL5N`?P0080001804P000000`d26P01
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000008000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 240, 7, 42, "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  InitializationCell->True],
Cell[1960, 58, 383, 10, 123, "Input",
  PageBreakWithin->Automatic,
  InitializationCell->True],
Cell[2346, 70, 500, 12, 149, "Input",
  PageBreakWithin->Automatic,
  InitializationCell->True],
Cell[2849, 84, 2059, 32, 565, "Input",
  PageBreakWithin->Automatic,
  InitializationCell->True],
Cell[4911, 118, 596, 13, 70, "Input",
  PageBreakWithin->Automatic,
  InitializationCell->True],
Cell[5510, 133, 418, 10, 70, "Input",
  PageBreakWithin->Automatic,
  InitializationCell->True],
Cell[5931, 145, 752, 15, 70, "Input",
  PageBreakWithin->Automatic,
  InitializationCell->True],
Cell[6686, 162, 8312, 124, 70, "Input",
  PageBreakWithin->Automatic,
  InitializationCell->True],
Cell[15001, 288, 888, 18, 70, "Input",
  PageBreakWithin->Automatic,
  InitializationCell->True],
Cell[15892, 308, 1934, 34, 70, "Input",
  PageBreakWithin->Automatic,
  InitializationCell->True],
Cell[17829, 344, 596, 13, 70, "Input",
  PageBreakWithin->Automatic,
  InitializationCell->True],
Cell[18428, 359, 541, 13, 70, "Input",
  PageBreakWithin->Automatic,
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

